==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property comparator The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
 * @property tagValues The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs(
    public val comparator: Output<String>? = null,
    public val tagValues:
    Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs> {
    override fun toJava():
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.builder()
            .comparator(comparator?.applyValue({ args0 -> args0 }))
            .tagValues(
                tagValues?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgsBuilder
internal constructor() {
    private var comparator: Output<String>? = null

    private var tagValues:
        Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>? =
        null

    /**
     * @param value The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
     */
    @JvmName("qtgopvybnskieibj")
    public suspend fun comparator(`value`: Output<String>) {
        this.comparator = value
    }

    /**
     * @param value The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("gbtrftabgayvsckx")
    public suspend
    fun tagValues(`value`: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>) {
        this.tagValues = value
    }

    @JvmName("vqnwcwbexvtkodin")
    public suspend fun tagValues(
        vararg
        values: Output<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>,
    ) {
        this.tagValues = Output.all(values.asList())
    }

    /**
     * @param values The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("eauvhsyjpqwwaion")
    public suspend
    fun tagValues(values: List<Output<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>) {
        this.tagValues = Output.all(values)
    }

    /**
     * @param value The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
     */
    @JvmName("htwertnxxskicqiv")
    public suspend fun comparator(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.comparator = mapped
    }

    /**
     * @param value The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("duoexlufqjetwwep")
    public suspend
    fun tagValues(`value`: List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("kihgkocihaswhmbx")
    public suspend
    fun tagValues(argument: List<suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("ejbxnwaiykalmdcv")
    public suspend fun tagValues(
        vararg
        argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("jcyfixgmxmjuqflh")
    public suspend
    fun tagValues(argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend
                    { argument() }.build(),
            )
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param values The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("nllmfhcngakbtppk")
    public suspend fun tagValues(
        vararg
        values: ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tagValues = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs(
            comparator = comparator,
            tagValues = tagValues,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property comparator The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
 * @property tagValues The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs(
    public val comparator: Output<String>? = null,
    public val tagValues: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs> {
    override fun toJava(): com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs.builder()
            .comparator(comparator?.applyValue({ args0 -> args0 }))
            .tagValues(
                tagValues?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgsBuilder
internal constructor() {
    private var comparator: Output<String>? = null

    private var tagValues:
        Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>? =
        null

    /**
     * @param value The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
     */
    @JvmName("mqthauhgutbmrwpf")
    public suspend fun comparator(`value`: Output<String>) {
        this.comparator = value
    }

    /**
     * @param value The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("jmeormyvrsyfrbvb")
    public suspend fun tagValues(`value`: Output<List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>) {
        this.tagValues = value
    }

    @JvmName("ljocvjfkimxepxqk")
    public suspend fun tagValues(vararg values: Output<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>) {
        this.tagValues = Output.all(values.asList())
    }

    /**
     * @param values The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("duuxxlfqnqqrvgon")
    public suspend fun tagValues(values: List<Output<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>>) {
        this.tagValues = Output.all(values)
    }

    /**
     * @param value The operator to use in the condition. Valid combination and values are available in the [AWS Documentation](https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html#jobs-model-jobcomparator)
     */
    @JvmName("hiqmcbbuyrxyrlko")
    public suspend fun comparator(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.comparator = mapped
    }

    /**
     * @param value The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("ngmetxmvtitcwjel")
    public suspend fun tagValues(`value`: List<ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("jxumvjdyyhobnyni")
    public suspend fun tagValues(argument: List<suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("cxgvxwgdofdtbumb")
    public suspend fun tagValues(vararg argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param argument The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("milphrmfoarqkvwf")
    public suspend fun tagValues(argument: suspend ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder().applySuspend
                    { argument() }.build(),
            )
        val mapped = of(toBeMapped)
        this.tagValues = mapped
    }

    /**
     * @param values The  tag key and value pairs to use in the condition. One or more blocks are allowed. (documented below)
     */
    @JvmName("uyjrckfxughhmvgk")
    public suspend fun tagValues(vararg values: ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tagValues = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionArgs(
            comparator = comparator,
            tagValues = tagValues,
        )
}
